Datasets
--------------------

dacy.datasets.dane
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: dacy.datasets.dane
   :members:
   :undoc-members:
   :show-inheritance:


dacy.datasets.names
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: dacy.datasets.names
   :members:
   :undoc-members:
   :show-inheritance:
